/* eslint-disable */
import { Typography } from '@material-ui/core';
import React, { useState } from 'react';
import { useTranslation } from 'react-i18next';
import { useSelector } from 'react-redux';
import ButtonOutline from '../../../components/Button/ButtonOutline';
import { RootState } from '../../../redux/reducers';
import timeDifference from '../../../utils/datesModifier';
import NodeLogs from '../NodeLogs';
import ChaosResult from '../ChaosResult';
import useStyles from './styles';

interface WorkflowNodeInfoProps {
  cluster_id: string;
  workflow_run_id: string;
  pod_namespace: string;
}

const WorkflowNodeInfo: React.FC<WorkflowNodeInfoProps> = ({
  cluster_id,
  workflow_run_id,
  pod_namespace,
}) => {
  const classes = useStyles();
  const { t } = useTranslation();

  const [logsOpen, setLogsOpen] = useState<boolean>(false);
  const [resultModal, setResultModal] = useState(false);
  // Get the nelected node from redux
  const { name, phase, pod_name, type, startedAt, finishedAt } = useSelector(
    (state: RootState) => state.selectedNode
  );

  const handleClose = () => {
    setLogsOpen(false);
  };
  const handleResultClose = () => {
    setResultModal(false);
  };
  return (
    <div className={classes.root}>
      {/* Logs Modal */}
      {logsOpen ? (
        <NodeLogs
          logsOpen={logsOpen}
          handleClose={handleClose}
          cluster_id={cluster_id}
          workflow_run_id={workflow_run_id}
          pod_namespace={pod_namespace}
          pod_name={pod_name}
          pod_type={type}
        />
      ) : (
        <></>
      )}
      {/* Chaos Result Modal */}
      {resultModal ? (
        <ChaosResult
          chaosResultOpen={resultModal}
          handleResultClose={handleResultClose}
          workflow_run_id={workflow_run_id}
          pod_name={pod_name}
        />
      ) : null}
      {/* Node Type */}
      <div className={classes.heightMaintainer}>
        <Typography className={classes.nodeSpacing}>
          <span className={classes.bold}>
            {t('workflowDetailsView.workflowNodeInfo.type')}:
          </span>{' '}
          {type}
        </Typography>
      </div>
      <hr />

      {/* Node Phase */}
      <div className={classes.nodeSpacing}>
        <div className={classes.heightMaintainer}>
          <Typography>
            <span className={classes.bold}>
              {t('workflowDetailsView.workflowNodeInfo.phase')}:
            </span>{' '}
            {phase}
          </Typography>
        </div>
      </div>
      <hr />

      {/* Node Durations */}
      <div className={classes.nodeSpacing}>
        <div className={classes.heightMaintainer}>
          <Typography>
            <span className={classes.bold}>
              {t('workflowDetailsView.workflowNodeInfo.startTime')}:
            </span>{' '}
            {timeDifference(startedAt)}
          </Typography>
          <Typography>
            <span className={classes.bold}>
              {t('workflowDetailsView.workflowNodeInfo.endTime')}:
            </span>{' '}
            {finishedAt !== ''
              ? timeDifference(finishedAt)
              : 'Not yet finished'}
          </Typography>
          <Typography>
            <span className={classes.bold}>
              {t('workflowDetailsView.workflowNodeInfo.duration')}:{' '}
            </span>{' '}
            {finishedAt !== ''
              ? (
                  (parseInt(finishedAt, 10) - parseInt(startedAt, 10)) /
                  60
                ).toFixed(1)
              : (
                  (new Date().getTime() / 1000 - parseInt(startedAt, 10)) /
                  60
                ).toFixed(1)}{' '}
            minutes
          </Typography>
        </div>
      </div>
      <hr />
      {/* Step Name */}
      <div className={classes.nodeSpacing}>
        <div className={classes.heightMaintainer}>
          <Typography>
            <span className={classes.bold}>
              {t('workflowDetailsView.workflowNodeInfo.nodeName')}:
            </span>{' '}
            {name}
          </Typography>
        </div>
      </div>
      <div className={classes.footerButton}>
        <ButtonOutline isDisabled={false} handleClick={() => setLogsOpen(true)}>
          {t('workflowDetailsView.workflowNodeInfo.button.logs')}
        </ButtonOutline>
        <div className={classes.resultBtn}>
          {type === 'ChaosEngine' ? (
            <ButtonOutline
              isDisabled={false}
              handleClick={() => setResultModal(true)}
            >
              {t('workflowDetailsView.workflowNodeInfo.button.result')}
            </ButtonOutline>
          ) : null}
        </div>
      </div>
    </div>
  );
};

export default WorkflowNodeInfo;
